Contributing to Dokang
----------------------

Dokang is hosted on GitHub at https://github.com/polyconseil/dokang/.
Suggestions and patches are welcome.

Dokang is good enough for us for now, but here are some vague plans:

- adding autocomplete on the search field in the web frontend;

- providing better search results by tweaking Whoosh configuration;

- making the configuration easier.

Dokang is written by Polyconseil and is licensed under the 3-clause
BSD license, a copy of which is included in the source and reproduced
below:

.. include:: ../LICENSE.txt
